diff --git a/.gitignore b/.gitignore
index b7f198a..af567ea 100644
--- a/.gitignore
+++ b/.gitignore
@@ -1,3 +1,4 @@
node_modules/*
!node_modules/q
-!node_modules/child_process
\ No newline at end of file
+!node_modules/child_process
+.DS_Store
diff --git a/node_modules/xcode/.travis.yml b/node_modules/xcode/.travis.yml
index 14a176e..44b04f9 100644
--- a/node_modules/xcode/.travis.yml
+++ b/node_modules/xcode/.travis.yml
@@ -8,6 +8,11 @@ node_js:
- 6
- 8
- 10
+ - 12
+
+os:
+ - linux
+ - osx
install:
- nvm --version
diff --git a/node_modules/xcode/RELEASENOTES.md b/node_modules/xcode/RELEASENOTES.md
index e07fac2..ac2916d 100644
--- a/node_modules/xcode/RELEASENOTES.md
+++ b/node_modules/xcode/RELEASENOTES.md
@@ -20,6 +20,20 @@
-->
# Cordova-node-xcode Release Notes
+### 2.1.0 (December 12, 2019)
+* Add target test coverage ([#82](https://github.com/apache/cordova-node-xcode/pull/82))
+* ensure coverage for addTargetDependency with invalid input ([#81](https://github.com/apache/cordova-node-xcode/pull/81))
+* Support watch2 apps/extensions ([#56](https://github.com/apache/cordova-node-xcode/pull/56))
+* Test coverage: `addTarget` add to main project as dependency ([#76](https://github.com/apache/cordova-node-xcode/pull/76))
+* remove internal propReplace function not needed ([#69](https://github.com/apache/cordova-node-xcode/pull/69))
+* Add proper `filetypeForProducttype` test coverage ([#72](https://github.com/apache/cordova-node-xcode/pull/72))
+* Test existing WatchKit support ([#71](https://github.com/apache/cordova-node-xcode/pull/71))
+* fix a comment in lib/pbxProject.js ([#68](https://github.com/apache/cordova-node-xcode/pull/68))
+* Test coverage for `app_extension` target types ([#66](https://github.com/apache/cordova-node-xcode/pull/66))
+* add dependencies for per-file testing ([#67](https://github.com/apache/cordova-node-xcode/pull/67))
+* Add Node.js 12 to CI Services ([#51](https://github.com/apache/cordova-node-xcode/pull/51))
+* Update writeObjectsSections to match current Xcode format ([#46](https://github.com/apache/cordova-node-xcode/pull/46))
+
### 2.0.0 (Jan 15, 2019)
* Updated to use ECMAScript 2015 Object.assign. ([#14](https://github.com/apache/cordova-node-xcode/pull/14))
* fix: simple-plist@1 update in dependencies ([#30](https://github.com/apache/cordova-node-xcode/pull/30))
diff --git a/node_modules/xcode/lib/pbxWriter.js b/node_modules/xcode/lib/pbxWriter.js
index 1f266d9..d297bc7 100644
--- a/node_modules/xcode/lib/pbxWriter.js
+++ b/node_modules/xcode/lib/pbxWriter.js
@@ -178,15 +178,10 @@ pbxWriter.prototype.writeObject = function (object) {
}
pbxWriter.prototype.writeObjectsSections = function (objects) {
- var first = true,
- key, obj;
+ var key, obj;
for (key in objects) {
- if (!first) {
- this.writeFlush("\n")
- } else {
- first = false;
- }
+ this.writeFlush("\n")
obj = objects[key];
diff --git a/node_modules/xcode/package.json b/node_modules/xcode/package.json
index 656a248..948852f 100644
--- a/node_modules/xcode/package.json
+++ b/node_modules/xcode/package.json
@@ -1,8 +1,8 @@
{
"_from": "xcode@^2.0.0",
- "_id": "xcode@2.0.0",
+ "_id": "xcode@2.1.0",
"_inBundle": false,
- "_integrity": "sha512-5xF6RCjAdDEiEsbbZaS/gBRt3jZ/177otZcpoLCjGN/u1LrfgH7/Sgeeavpr/jELpyDqN2im3AKosl2G2W8hfw==",
+ "_integrity": "sha512-uCrmPITrqTEzhn0TtT57fJaNaw8YJs1aCzs+P/QqxsDbvPZSv7XMPPwXrKvHtD6pLjBM/NaVwraWJm8q83Y4iQ==",
"_location": "/com.outsystems.imageeditorplugin/xcode",
"_phantomChildren": {},
"_requested": {
@@ -18,10 +18,10 @@
"_requiredBy": [
"/com.outsystems.imageeditorplugin"
],
- "_resolved": "https://registry.npmjs.org/xcode/-/xcode-2.0.0.tgz",
- "_shasum": "134f1f94c26fbfe8a9aaa9724bfb2772419da1a2",
+ "_resolved": "https://registry.npmjs.org/xcode/-/xcode-2.1.0.tgz",
+ "_shasum": "bab64a7e954bb50ca8d19da7e09531c65a43ecfe",
"_spec": "xcode@^2.0.0",
- "_where": "/Users/veyron/Work/Outsystems/Plugins/ImageEditor/cordova/image-editor-plugin",
+ "_where": "/Users/andregrillo/Documents/Outsystems/Troubleshooting/imageEditor/image-editor-plugin",
"author": {
"name": "Apache Software Foundation"
},
@@ -75,5 +75,5 @@
"pegjs": "pegjs lib/parser/pbxproj.pegjs",
"test": "nodeunit test/parser test"
},
- "version": "2.0.0"
+ "version": "2.1.0"
}
diff --git a/plugin.xml b/plugin.xml
index eb37ebf..c45dcf3 100644
--- a/plugin.xml
+++ b/plugin.xml
@@ -12,7 +12,12 @@
+
+
+
-
+
+
+ -->
+
diff --git a/src/ios/ImageEditorPlugin.swift b/src/ios/ImageEditorPlugin.swift
index b20273e..e39811c 100644
--- a/src/ios/ImageEditorPlugin.swift
+++ b/src/ios/ImageEditorPlugin.swift
@@ -12,7 +12,7 @@ import OSPhotoEditor
func editImage(_ command: CDVInvokedUrlCommand) {
self.callbackId = command.callbackId;
- var sourceType = UIImagePickerControllerSourceType.photoLibrary;
+ var sourceType = UIImagePickerController.SourceType.photoLibrary;
let sourceTypeString = command.arguments[0] as? String;
if ( sourceTypeString == "sourcetype" ){
if (command.arguments[1] as? String == "camera"){
@@ -101,10 +101,10 @@ extension ImageEditorPlugin: PhotoEditorDelegate {
extension ImageEditorPlugin: UIImagePickerControllerDelegate, UINavigationControllerDelegate {
- func imagePickerController(_ picker: UIImagePickerController,
- didFinishPickingMediaWithInfo info: [String : Any]) {
+ func imagePickerController(_ picker: UIImagePickerController,
+ didFinishPickingMediaWithInfo info: [UIImagePickerController.InfoKey : Any]) {
- guard let image = info[UIImagePickerControllerOriginalImage] as? UIImage else {
+ guard let image = info[UIImagePickerController.InfoKey.originalImage] as? UIImage else {
picker.dismiss(animated: true, completion: nil)
return
}
@@ -123,7 +123,7 @@ extension UIImage {
public func toBase64() -> String? {
let imageData: Data?
- imageData = UIImageJPEGRepresentation(self, 1)//compression
+ imageData = self.jpegData(compressionQuality: 1)//compression
return imageData?.base64EncodedString()
}
}
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib
deleted file mode 100644
index 60b4664..0000000
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib and /dev/null differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/objects-13.0+.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/objects-13.0+.nib
new file mode 100644
index 0000000..6e83903
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/objects-13.0+.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/runtime.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/runtime.nib
new file mode 100644
index 0000000..fa4d6dd
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/runtime.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib
deleted file mode 100644
index 3ed49e3..0000000
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib and /dev/null differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/objects-13.0+.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/objects-13.0+.nib
new file mode 100644
index 0000000..7b0c41b
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/objects-13.0+.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/runtime.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/runtime.nib
new file mode 100644
index 0000000..68011f0
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Base.lproj/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/runtime.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/ColorCollectionViewCell.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/ColorCollectionViewCell.nib
deleted file mode 100644
index 2cf8d79..0000000
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/ColorCollectionViewCell.nib and /dev/null differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/ColorCollectionViewCell.nib/objects-12.3+.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/ColorCollectionViewCell.nib/objects-12.3+.nib
new file mode 100644
index 0000000..06b2f95
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/ColorCollectionViewCell.nib/objects-12.3+.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/ColorCollectionViewCell.nib/objects-13.0+.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/ColorCollectionViewCell.nib/objects-13.0+.nib
new file mode 100644
index 0000000..0798361
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/ColorCollectionViewCell.nib/objects-13.0+.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/ColorCollectionViewCell.nib/runtime.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/ColorCollectionViewCell.nib/runtime.nib
new file mode 100644
index 0000000..293fe4d
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/ColorCollectionViewCell.nib/runtime.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/EmojiCollectionViewCell.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/EmojiCollectionViewCell.nib
deleted file mode 100644
index 8b49ad5..0000000
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/EmojiCollectionViewCell.nib and /dev/null differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/EmojiCollectionViewCell.nib/objects-12.3+.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/EmojiCollectionViewCell.nib/objects-12.3+.nib
new file mode 100644
index 0000000..0de93c3
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/EmojiCollectionViewCell.nib/objects-12.3+.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/EmojiCollectionViewCell.nib/objects-13.0+.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/EmojiCollectionViewCell.nib/objects-13.0+.nib
new file mode 100644
index 0000000..65ed725
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/EmojiCollectionViewCell.nib/objects-13.0+.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/EmojiCollectionViewCell.nib/runtime.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/EmojiCollectionViewCell.nib/runtime.nib
new file mode 100644
index 0000000..761df5b
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/EmojiCollectionViewCell.nib/runtime.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Headers/OSPhotoEditor-Swift.h b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Headers/OSPhotoEditor-Swift.h
index 4f61a49..7aa44be 100644
--- a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Headers/OSPhotoEditor-Swift.h
+++ b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Headers/OSPhotoEditor-Swift.h
@@ -1,4 +1,4 @@
-// Generated by Apple Swift version 4.2.1 (swiftlang-1000.11.42 clang-1000.11.45.1)
+// Generated by Apple Swift version 5.1 (swiftlang-1100.0.270.13 clang-1100.0.33.7)
#pragma clang diagnostic push
#pragma clang diagnostic ignored "-Wgcc-compat"
@@ -20,7 +20,7 @@
#endif
#pragma clang diagnostic ignored "-Wauto-import"
-#include
+#include
#include
#include
#include
@@ -110,6 +110,15 @@ typedef unsigned int swift_uint4 __attribute__((__ext_vector_type__(4)));
# define SWIFT_CLASS_NAMED(SWIFT_NAME) SWIFT_COMPILE_NAME(SWIFT_NAME) SWIFT_CLASS_EXTRA
# endif
#endif
+#if !defined(SWIFT_RESILIENT_CLASS)
+# if __has_attribute(objc_class_stub)
+# define SWIFT_RESILIENT_CLASS(SWIFT_NAME) SWIFT_CLASS(SWIFT_NAME) __attribute__((objc_class_stub))
+# define SWIFT_RESILIENT_CLASS_NAMED(SWIFT_NAME) __attribute__((objc_class_stub)) SWIFT_CLASS_NAMED(SWIFT_NAME)
+# else
+# define SWIFT_RESILIENT_CLASS(SWIFT_NAME) SWIFT_CLASS(SWIFT_NAME)
+# define SWIFT_RESILIENT_CLASS_NAMED(SWIFT_NAME) SWIFT_CLASS_NAMED(SWIFT_NAME)
+# endif
+#endif
#if !defined(SWIFT_PROTOCOL)
# define SWIFT_PROTOCOL(SWIFT_NAME) SWIFT_RUNTIME_NAME(SWIFT_NAME) SWIFT_PROTOCOL_EXTRA
@@ -151,6 +160,9 @@ typedef unsigned int swift_uint4 __attribute__((__ext_vector_type__(4)));
#if !defined(SWIFT_AVAILABILITY)
# define SWIFT_AVAILABILITY(plat, ...) __attribute__((availability(plat, __VA_ARGS__)))
#endif
+#if !defined(SWIFT_WEAK_IMPORT)
+# define SWIFT_WEAK_IMPORT __attribute__((weak_import))
+#endif
#if !defined(SWIFT_DEPRECATED)
# define SWIFT_DEPRECATED __attribute__((deprecated))
#endif
@@ -162,7 +174,13 @@ typedef unsigned int swift_uint4 __attribute__((__ext_vector_type__(4)));
#else
# define SWIFT_DEPRECATED_OBJC(Msg) SWIFT_DEPRECATED_MSG(Msg)
#endif
+#if !defined(IBSegueAction)
+# define IBSegueAction
+#endif
#if __has_feature(modules)
+#if __has_warning("-Watimport-in-framework-header")
+#pragma clang diagnostic ignored "-Watimport-in-framework-header"
+#endif
@import CoreGraphics;
@import Foundation;
@import ObjectiveC;
@@ -209,7 +227,7 @@ SWIFT_CLASS("_TtC13OSPhotoEditor23ColorCollectionViewCell")
- (void)layoutSubviews;
@property (nonatomic, getter=isSelected) BOOL selected;
- (nonnull instancetype)initWithFrame:(CGRect)frame OBJC_DESIGNATED_INITIALIZER;
-- (nullable instancetype)initWithCoder:(NSCoder * _Nonnull)aDecoder OBJC_DESIGNATED_INITIALIZER;
+- (nullable instancetype)initWithCoder:(NSCoder * _Nonnull)coder OBJC_DESIGNATED_INITIALIZER;
@end
@class UIColor;
@@ -356,7 +374,7 @@ SWIFT_CLASS("_TtC13OSPhotoEditor23EmojiCollectionViewCell")
@property (nonatomic, weak) IBOutlet UILabel * _Null_unspecified emojiLabel;
- (void)awakeFromNib;
- (nonnull instancetype)initWithFrame:(CGRect)frame OBJC_DESIGNATED_INITIALIZER;
-- (nullable instancetype)initWithCoder:(NSCoder * _Nonnull)aDecoder OBJC_DESIGNATED_INITIALIZER;
+- (nullable instancetype)initWithCoder:(NSCoder * _Nonnull)coder OBJC_DESIGNATED_INITIALIZER;
@end
@class UICollectionViewLayout;
@@ -383,7 +401,7 @@ SWIFT_CLASS("_TtC13OSPhotoEditor12GradientView")
- (void)awakeFromNib;
- (void)layoutSubviews;
- (nonnull instancetype)initWithFrame:(CGRect)frame OBJC_DESIGNATED_INITIALIZER;
-- (nullable instancetype)initWithCoder:(NSCoder * _Nonnull)aDecoder OBJC_DESIGNATED_INITIALIZER;
+- (nullable instancetype)initWithCoder:(NSCoder * _Nonnull)coder OBJC_DESIGNATED_INITIALIZER;
@end
@@ -460,7 +478,7 @@ SWIFT_CLASS("_TtC13OSPhotoEditor25PhotoEditorViewController")
- (void)setImageViewWithImage:(UIImage * _Nonnull)image;
- (void)hideToolbarWithHide:(BOOL)hide;
- (nonnull instancetype)initWithNibName:(NSString * _Nullable)nibNameOrNil bundle:(NSBundle * _Nullable)nibBundleOrNil OBJC_DESIGNATED_INITIALIZER;
-- (nullable instancetype)initWithCoder:(NSCoder * _Nonnull)aDecoder OBJC_DESIGNATED_INITIALIZER;
+- (nullable instancetype)initWithCoder:(NSCoder * _Nonnull)coder OBJC_DESIGNATED_INITIALIZER;
@end
@@ -608,7 +626,7 @@ SWIFT_CLASS("_TtC13OSPhotoEditor25StickerCollectionViewCell")
@property (nonatomic, weak) IBOutlet UIImageView * _Null_unspecified stickerImage;
- (void)awakeFromNib;
- (nonnull instancetype)initWithFrame:(CGRect)frame OBJC_DESIGNATED_INITIALIZER;
-- (nullable instancetype)initWithCoder:(NSCoder * _Nonnull)aDecoder OBJC_DESIGNATED_INITIALIZER;
+- (nullable instancetype)initWithCoder:(NSCoder * _Nonnull)coder OBJC_DESIGNATED_INITIALIZER;
@end
@class UIPageControl;
@@ -637,7 +655,7 @@ SWIFT_CLASS("_TtC13OSPhotoEditor22StickersViewController")
- (void)removeBottomSheetView;
- (void)prepareBackgroundView;
- (nonnull instancetype)initWithNibName:(NSString * _Nullable)nibNameOrNil bundle:(NSBundle * _Nullable)nibBundleOrNil OBJC_DESIGNATED_INITIALIZER;
-- (nullable instancetype)initWithCoder:(NSCoder * _Nonnull)aDecoder OBJC_DESIGNATED_INITIALIZER;
+- (nullable instancetype)initWithCoder:(NSCoder * _Nonnull)coder OBJC_DESIGNATED_INITIALIZER;
@end
@@ -657,12 +675,6 @@ SWIFT_CLASS("_TtC13OSPhotoEditor22StickersViewController")
-SWIFT_CLASS("_TtC13OSPhotoEditor7TestOla")
-@interface TestOla : NSObject
-- (nonnull instancetype)init OBJC_DESIGNATED_INITIALIZER;
-@end
-
-
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Info.plist b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Info.plist
index c2cd1ee..87abaae 100644
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Info.plist and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Info.plist differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib
deleted file mode 100644
index 7717f56..0000000
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib and /dev/null differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/objects-13.0+.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/objects-13.0+.nib
new file mode 100644
index 0000000..bd16adf
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/objects-13.0+.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/runtime.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/runtime.nib
new file mode 100644
index 0000000..de28c8d
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/runtime.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib
deleted file mode 100644
index 79ae53f..0000000
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib and /dev/null differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/objects-13.0+.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/objects-13.0+.nib
new file mode 100644
index 0000000..a5218e3
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/objects-13.0+.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/runtime.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/runtime.nib
new file mode 100644
index 0000000..b8435f0
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/runtime.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm.swiftdoc b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm.swiftdoc
index 624dae2..dfaa155 100644
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm.swiftdoc and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm.swiftdoc differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm.swiftmodule b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm.swiftmodule
index 46910ab..a616d1d 100644
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm.swiftmodule and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm.swiftmodule differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm64.swiftdoc b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm64.swiftdoc
index 3e98a31..66c5f26 100644
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm64.swiftdoc and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm64.swiftdoc differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm64.swiftmodule b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm64.swiftmodule
index b45ee79..4e23ab0 100644
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm64.swiftmodule and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/arm64.swiftmodule differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/i386.swiftdoc b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/i386.swiftdoc
index 86e6df5..1054794 100644
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/i386.swiftdoc and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/i386.swiftdoc differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/i386.swiftmodule b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/i386.swiftmodule
index 86823bd..ce7e579 100644
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/i386.swiftmodule and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/i386.swiftmodule differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/x86_64.swiftdoc b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/x86_64.swiftdoc
index 46179fa..3647b7c 100644
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/x86_64.swiftdoc and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/x86_64.swiftdoc differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/x86_64.swiftmodule b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/x86_64.swiftmodule
index 13b49b9..4d40b21 100644
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/x86_64.swiftmodule and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/Modules/OSPhotoEditor.swiftmodule/x86_64.swiftmodule differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/OSPhotoEditor b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/OSPhotoEditor
index 125f337..b37acfd 100755
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/OSPhotoEditor and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/OSPhotoEditor differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/PhotoEditorViewController.nib/objects-11.0+.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/PhotoEditorViewController.nib/objects-11.0+.nib
index 3737751..eea6aff 100644
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/PhotoEditorViewController.nib/objects-11.0+.nib and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/PhotoEditorViewController.nib/objects-11.0+.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/PhotoEditorViewController.nib/objects-13.0+.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/PhotoEditorViewController.nib/objects-13.0+.nib
new file mode 100644
index 0000000..7b906ab
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/PhotoEditorViewController.nib/objects-13.0+.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/PhotoEditorViewController.nib/runtime.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/PhotoEditorViewController.nib/runtime.nib
index bf86bf5..5699372 100644
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/PhotoEditorViewController.nib/runtime.nib and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/PhotoEditorViewController.nib/runtime.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickerCollectionViewCell.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickerCollectionViewCell.nib
deleted file mode 100644
index 2e0f841..0000000
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickerCollectionViewCell.nib and /dev/null differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickerCollectionViewCell.nib/objects-12.3+.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickerCollectionViewCell.nib/objects-12.3+.nib
new file mode 100644
index 0000000..1c87270
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickerCollectionViewCell.nib/objects-12.3+.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickerCollectionViewCell.nib/objects-13.0+.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickerCollectionViewCell.nib/objects-13.0+.nib
new file mode 100644
index 0000000..2d5f480
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickerCollectionViewCell.nib/objects-13.0+.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickerCollectionViewCell.nib/runtime.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickerCollectionViewCell.nib/runtime.nib
new file mode 100644
index 0000000..7c792cc
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickerCollectionViewCell.nib/runtime.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickersViewController.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickersViewController.nib
deleted file mode 100644
index b31ab61..0000000
Binary files a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickersViewController.nib and /dev/null differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickersViewController.nib/objects-13.0+.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickersViewController.nib/objects-13.0+.nib
new file mode 100644
index 0000000..19ce981
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickersViewController.nib/objects-13.0+.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickersViewController.nib/runtime.nib b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickersViewController.nib/runtime.nib
new file mode 100644
index 0000000..e447336
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/StickersViewController.nib/runtime.nib differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/_CodeSignature/CodeResources b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/_CodeSignature/CodeResources
new file mode 100644
index 0000000..3eddafe
--- /dev/null
+++ b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.framework/_CodeSignature/CodeResources
@@ -0,0 +1,627 @@
+
+
+
+
+ files
+
+ Base.lproj/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/objects-13.0+.nib
+
+ zkt5BzyzqTwJa2pYeADmO92/EYM=
+
+ Base.lproj/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/runtime.nib
+
+ Z+dz/tVXjgR9zHpjTMEgzgeof9c=
+
+ Base.lproj/LaunchScreen.storyboardc/Info.plist
+
+ n2t8gsDpfE6XkhG31p7IQJRxTxU=
+
+ Base.lproj/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/objects-13.0+.nib
+
+ Y//ilSO7TgyDyqj2oUPR78souFE=
+
+ Base.lproj/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/runtime.nib
+
+ P3zZV45VffkeKHu/rraVeM4GUTA=
+
+ ColorCollectionViewCell.nib/objects-12.3+.nib
+
+ dppCI4ek4RFG0Jq50OOz6yKDG80=
+
+ ColorCollectionViewCell.nib/objects-13.0+.nib
+
+ QCy63nV1o+30SRbbqPECH5N2IFI=
+
+ ColorCollectionViewCell.nib/runtime.nib
+
+ sxDMQ+fJeUy0AfeSG/pL2i8gw6I=
+
+ EmojiCollectionViewCell.nib/objects-12.3+.nib
+
+ G4FuiZOCyTlGXFPXpbxDP0z7q44=
+
+ EmojiCollectionViewCell.nib/objects-13.0+.nib
+
+ S5e/QMImFWHeJ7bpp9VGr2ArScM=
+
+ EmojiCollectionViewCell.nib/runtime.nib
+
+ YY/dDRfVTuxYislTbPqxVPKHi4Q=
+
+ Headers/OSPhotoEditor-Swift.h
+
+ yFCtZcsRCgU0R1ztH1i7rk8kSdk=
+
+ Headers/OSPhotoEditor.h
+
+ ikdhxVBo4w72fqNsfEfaTGNANxg=
+
+ Info.plist
+
+ 6aS2GyXKURPLJXuKM/kF0FMJyWE=
+
+ LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/objects-13.0+.nib
+
+ SnlRCohdj0Fpw3Hbk5tndOLb33w=
+
+ LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/runtime.nib
+
+ hnNesQZvLPErlJoBY3MbbJ9g264=
+
+ LaunchScreen.storyboardc/Info.plist
+
+ n2t8gsDpfE6XkhG31p7IQJRxTxU=
+
+ LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/objects-13.0+.nib
+
+ Oqci8uFs+pHrzC/KWjgSwfoR40Y=
+
+ LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/runtime.nib
+
+ QCdvaUYxKwnaIbHh65q+QINyjOc=
+
+ Modules/OSPhotoEditor.swiftmodule/arm.swiftdoc
+
+ z4z0xcrmBpeVO/f7/MdyT8oJlU4=
+
+ Modules/OSPhotoEditor.swiftmodule/arm.swiftmodule
+
+ 7/hZWj5L0pY5iq5Irglr1mKYiok=
+
+ Modules/OSPhotoEditor.swiftmodule/arm64.swiftdoc
+
+ EiTsB1WikcI1+fkd2hMI3ZLKQfs=
+
+ Modules/OSPhotoEditor.swiftmodule/arm64.swiftmodule
+
+ 0fBRzWGU7UBRFY37j7CZp25/9qA=
+
+ Modules/module.modulemap
+
+ oRHxZ9UCaPV7cZuzN35q4XVXvWA=
+
+ PhotoCropEditorBorder.png
+
+ I8JAxqFexuMbMM0kPiZKdeQ79U8=
+
+ PhotoCropEditorBorder@2x.png
+
+ 72rJWpl9JtxcZgKXbBTFSHLDIGE=
+
+ PhotoCropEditorBorder@3x.png
+
+ 8b7K7tmX49LorhwDLdVwchCtMrE=
+
+ PhotoEditorViewController.nib/objects-11.0+.nib
+
+ lsmnYtwAcFF3dGdeQqVzhoOdbk4=
+
+ PhotoEditorViewController.nib/objects-13.0+.nib
+
+ xGisZdeDgQ/nTe94hILiCFGV2sk=
+
+ PhotoEditorViewController.nib/runtime.nib
+
+ MJWYTveIlA+4BVZQ/HX/aAU/L/M=
+
+ StickerCollectionViewCell.nib/objects-12.3+.nib
+
+ /VWEJKWXedOZM5ig4/YeYRS2An4=
+
+ StickerCollectionViewCell.nib/objects-13.0+.nib
+
+ 5EKC237Eiwbc0ay06e+lCaz2Z+k=
+
+ StickerCollectionViewCell.nib/runtime.nib
+
+ JXGXnoXfOU1aUouj4ugLVxlFh1M=
+
+ StickersViewController.nib/objects-13.0+.nib
+
+ 5VOt0swh34oJNXCcvu8wsffqMr4=
+
+ StickersViewController.nib/runtime.nib
+
+ ZdV77HbnjOAlt8tw7zJa0YqgzHU=
+
+ icomoon.ttf
+
+ 1uoWtHwW/rjAdE839ksSRHBtMlQ=
+
+
+ files2
+
+ Base.lproj/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/objects-13.0+.nib
+
+ hash
+
+ zkt5BzyzqTwJa2pYeADmO92/EYM=
+
+ hash2
+
+ aSXp0KC4mt4EL6nxXcNhcltarvrP6qhaozTZf+bvp58=
+
+
+ Base.lproj/LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/runtime.nib
+
+ hash
+
+ Z+dz/tVXjgR9zHpjTMEgzgeof9c=
+
+ hash2
+
+ rvGpWHF8lLk/sC8J2iFzLAsBDHYx8nkIAuTtX4swdI4=
+
+
+ Base.lproj/LaunchScreen.storyboardc/Info.plist
+
+ hash
+
+ n2t8gsDpfE6XkhG31p7IQJRxTxU=
+
+ hash2
+
+ HyVdXMU7Ux4/KalAao30mpWOK/lEPT4gvYN09wf31cg=
+
+
+ Base.lproj/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/objects-13.0+.nib
+
+ hash
+
+ Y//ilSO7TgyDyqj2oUPR78souFE=
+
+ hash2
+
+ fzskyWyxTZrOQX4w37bcyE5Xf7WsiBM2eCE3e9oCR8Q=
+
+
+ Base.lproj/LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/runtime.nib
+
+ hash
+
+ P3zZV45VffkeKHu/rraVeM4GUTA=
+
+ hash2
+
+ b/qSzRd8ykKjQs2/XJan7buXYSwOeGYWHK20G0anF4s=
+
+
+ ColorCollectionViewCell.nib/objects-12.3+.nib
+
+ hash
+
+ dppCI4ek4RFG0Jq50OOz6yKDG80=
+
+ hash2
+
+ B5Svf9Ys/lhFz63ETsKFbZ5ksaalwFcwn7FNel9IFUQ=
+
+
+ ColorCollectionViewCell.nib/objects-13.0+.nib
+
+ hash
+
+ QCy63nV1o+30SRbbqPECH5N2IFI=
+
+ hash2
+
+ zkBYAK+V+uU4UEr1+IUCFszEe5DxacXgz3zWKzXrXtU=
+
+
+ ColorCollectionViewCell.nib/runtime.nib
+
+ hash
+
+ sxDMQ+fJeUy0AfeSG/pL2i8gw6I=
+
+ hash2
+
+ pim3Vm2Z3UMl9ER1oSMfvNIglDXI7MLXwBiEsXr60a4=
+
+
+ EmojiCollectionViewCell.nib/objects-12.3+.nib
+
+ hash
+
+ G4FuiZOCyTlGXFPXpbxDP0z7q44=
+
+ hash2
+
+ 7AHrzh1romDiz0jnmHidbB0WrtP7QVd6JX8denbqHOU=
+
+
+ EmojiCollectionViewCell.nib/objects-13.0+.nib
+
+ hash
+
+ S5e/QMImFWHeJ7bpp9VGr2ArScM=
+
+ hash2
+
+ l+Mw2ssSndwqijSGR6VRgp0PTDIGKdb++u2IjyqdgGE=
+
+
+ EmojiCollectionViewCell.nib/runtime.nib
+
+ hash
+
+ YY/dDRfVTuxYislTbPqxVPKHi4Q=
+
+ hash2
+
+ nMGaHBHZkINsbHzUf7lSYExWhIke5Fgp+c0INXsUO3M=
+
+
+ Headers/OSPhotoEditor-Swift.h
+
+ hash
+
+ yFCtZcsRCgU0R1ztH1i7rk8kSdk=
+
+ hash2
+
+ Ni6Y+JnL9w0BuBTvu7CBlvXFf9askljizpqU9qmW3AI=
+
+
+ Headers/OSPhotoEditor.h
+
+ hash
+
+ ikdhxVBo4w72fqNsfEfaTGNANxg=
+
+ hash2
+
+ h2jQrTzNk3Ic8zwhh5gjM7dwUFNEgjyHtuKcOKjuV58=
+
+
+ LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/objects-13.0+.nib
+
+ hash
+
+ SnlRCohdj0Fpw3Hbk5tndOLb33w=
+
+ hash2
+
+ o92/taNMw9QIDkxxbj9cXMY+mcml4QVnHzr/9ab8/SM=
+
+
+ LaunchScreen.storyboardc/01J-lp-oVM-view-Ze5-6b-2t3.nib/runtime.nib
+
+ hash
+
+ hnNesQZvLPErlJoBY3MbbJ9g264=
+
+ hash2
+
+ T1Pf4jN12DM2cpxvdZSi+uUR9cLguB17FpWCDjuc/to=
+
+
+ LaunchScreen.storyboardc/Info.plist
+
+ hash
+
+ n2t8gsDpfE6XkhG31p7IQJRxTxU=
+
+ hash2
+
+ HyVdXMU7Ux4/KalAao30mpWOK/lEPT4gvYN09wf31cg=
+
+
+ LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/objects-13.0+.nib
+
+ hash
+
+ Oqci8uFs+pHrzC/KWjgSwfoR40Y=
+
+ hash2
+
+ PRuuTYdFQZD0DZ4bIQybA088MMBzxQcxpNzUCU57lsA=
+
+
+ LaunchScreen.storyboardc/UIViewController-01J-lp-oVM.nib/runtime.nib
+
+ hash
+
+ QCdvaUYxKwnaIbHh65q+QINyjOc=
+
+ hash2
+
+ s8lnZJGXoKTHSAoLzgOA8uwmb0b566dgEpo8JARpJ2s=
+
+
+ Modules/OSPhotoEditor.swiftmodule/arm.swiftdoc
+
+ hash
+
+ z4z0xcrmBpeVO/f7/MdyT8oJlU4=
+
+ hash2
+
+ oEV2CNZqSjGGdz2lwT14Qqf9TwgFGiP7t3c1VaCW8HA=
+
+
+ Modules/OSPhotoEditor.swiftmodule/arm.swiftmodule
+
+ hash
+
+ 7/hZWj5L0pY5iq5Irglr1mKYiok=
+
+ hash2
+
+ ZACL7Y+UYSD9ciUgCaolTYx/30zabgPGbciwCbKHHbc=
+
+
+ Modules/OSPhotoEditor.swiftmodule/arm64.swiftdoc
+
+ hash
+
+ EiTsB1WikcI1+fkd2hMI3ZLKQfs=
+
+ hash2
+
+ WnUgXBrxe8oDMi5R/loW2NrX9ahHA/9+LC71+RFXGWY=
+
+
+ Modules/OSPhotoEditor.swiftmodule/arm64.swiftmodule
+
+ hash
+
+ 0fBRzWGU7UBRFY37j7CZp25/9qA=
+
+ hash2
+
+ Vbrodvpej32GU2sAm32OrGLa3+IkVpd03PIUAEMdPz0=
+
+
+ Modules/module.modulemap
+
+ hash
+
+ oRHxZ9UCaPV7cZuzN35q4XVXvWA=
+
+ hash2
+
+ m6m/CRx0r+kaWZWF7Qd3Ubz9UtBahYbcnm8mzlkp0P4=
+
+
+ PhotoCropEditorBorder.png
+
+ hash
+
+ I8JAxqFexuMbMM0kPiZKdeQ79U8=
+
+ hash2
+
+ U0DElXF2J/XKywS/THDWP0VfsH6nFXyZi8BmC8oZp5M=
+
+
+ PhotoCropEditorBorder@2x.png
+
+ hash
+
+ 72rJWpl9JtxcZgKXbBTFSHLDIGE=
+
+ hash2
+
+ J1xM0lF4W9UExvgpZmmCVEfFhqCZdP5EnaLl3xmYkJc=
+
+
+ PhotoCropEditorBorder@3x.png
+
+ hash
+
+ 8b7K7tmX49LorhwDLdVwchCtMrE=
+
+ hash2
+
+ eJahJD4iPAfVmj3SAug8GDKqX65rXURqWMY6foaNns8=
+
+
+ PhotoEditorViewController.nib/objects-11.0+.nib
+
+ hash
+
+ lsmnYtwAcFF3dGdeQqVzhoOdbk4=
+
+ hash2
+
+ RqEvTO3ujhqOhVt0tOxroKQtkn4gs41MWAKkCrQrxNs=
+
+
+ PhotoEditorViewController.nib/objects-13.0+.nib
+
+ hash
+
+ xGisZdeDgQ/nTe94hILiCFGV2sk=
+
+ hash2
+
+ +orgThKPl2KrUvEMb2F8X7o4V8bmsSfLQ02Ew+V4fIs=
+
+
+ PhotoEditorViewController.nib/runtime.nib
+
+ hash
+
+ MJWYTveIlA+4BVZQ/HX/aAU/L/M=
+
+ hash2
+
+ fn7yt0KNhOeBTastELXtqdx9Ie5+XJ8WBbL9ZxQXZ50=
+
+
+ StickerCollectionViewCell.nib/objects-12.3+.nib
+
+ hash
+
+ /VWEJKWXedOZM5ig4/YeYRS2An4=
+
+ hash2
+
+ dYN/coa0vP3t5lD8Xb+aiXecmHF35Q5cYqxfYd2bP/w=
+
+
+ StickerCollectionViewCell.nib/objects-13.0+.nib
+
+ hash
+
+ 5EKC237Eiwbc0ay06e+lCaz2Z+k=
+
+ hash2
+
+ 0wojHGDI4+gcyv4pmAmX3ossP6vKZMJeZc5NjsEaXao=
+
+
+ StickerCollectionViewCell.nib/runtime.nib
+
+ hash
+
+ JXGXnoXfOU1aUouj4ugLVxlFh1M=
+
+ hash2
+
+ J+CCi5Zq+drVvONKkSLeBsfi8/aCKSch6430Q21GWdY=
+
+
+ StickersViewController.nib/objects-13.0+.nib
+
+ hash
+
+ 5VOt0swh34oJNXCcvu8wsffqMr4=
+
+ hash2
+
+ mEEhy2w+smYxYKGNMc4JvP6mbzp2qL/16V5z98r38YI=
+
+
+ StickersViewController.nib/runtime.nib
+
+ hash
+
+ ZdV77HbnjOAlt8tw7zJa0YqgzHU=
+
+ hash2
+
+ CjcnRhLp9iK4NsGQullHHYVvCeIxLuScjpec6WRwz1o=
+
+
+ icomoon.ttf
+
+ hash
+
+ 1uoWtHwW/rjAdE839ksSRHBtMlQ=
+
+ hash2
+
+ ldCK2g8lFL7/baDS3qdKijQvEVow22tbzrVb0R+FHPA=
+
+
+
+ rules
+
+ ^.*
+
+ ^.*\.lproj/
+
+ optional
+
+ weight
+ 1000
+
+ ^.*\.lproj/locversion.plist$
+
+ omit
+
+ weight
+ 1100
+
+ ^Base\.lproj/
+
+ weight
+ 1010
+
+ ^version.plist$
+
+
+ rules2
+
+ .*\.dSYM($|/)
+
+ weight
+ 11
+
+ ^(.*/)?\.DS_Store$
+
+ omit
+
+ weight
+ 2000
+
+ ^.*
+
+ ^.*\.lproj/
+
+ optional
+
+ weight
+ 1000
+
+ ^.*\.lproj/locversion.plist$
+
+ omit
+
+ weight
+ 1100
+
+ ^Base\.lproj/
+
+ weight
+ 1010
+
+ ^Info\.plist$
+
+ omit
+
+ weight
+ 20
+
+ ^PkgInfo$
+
+ omit
+
+ weight
+ 20
+
+ ^embedded\.provisionprofile$
+
+ weight
+ 20
+
+ ^version\.plist$
+
+ weight
+ 20
+
+
+
+
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.xcodeproj/project.pbxproj b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.xcodeproj/project.pbxproj
index 3fed82b..4b56276 100644
--- a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.xcodeproj/project.pbxproj
+++ b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.xcodeproj/project.pbxproj
@@ -509,7 +509,7 @@
PRODUCT_NAME = "$(TARGET_NAME:c99extidentifier)";
SKIP_INSTALL = YES;
SWIFT_OPTIMIZATION_LEVEL = "-Onone";
- SWIFT_VERSION = 4.2;
+ SWIFT_VERSION = 5.0;
TARGETED_DEVICE_FAMILY = "1,2";
};
name = Debug;
@@ -534,7 +534,7 @@
PRODUCT_BUNDLE_IDENTIFIER = com.outsystems.osphotoeditor.OSPhotoEditor;
PRODUCT_NAME = "$(TARGET_NAME:c99extidentifier)";
SKIP_INSTALL = YES;
- SWIFT_VERSION = 4.2;
+ SWIFT_VERSION = 5.0;
TARGETED_DEVICE_FAMILY = "1,2";
};
name = Release;
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.xcodeproj/project.xcworkspace/xcuserdata/andregrillo.xcuserdatad/UserInterfaceState.xcuserstate b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.xcodeproj/project.xcworkspace/xcuserdata/andregrillo.xcuserdatad/UserInterfaceState.xcuserstate
new file mode 100644
index 0000000..f09d47b
Binary files /dev/null and b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.xcodeproj/project.xcworkspace/xcuserdata/andregrillo.xcuserdatad/UserInterfaceState.xcuserstate differ
diff --git a/src/ios/libs/OSPhotoEditor/OSPhotoEditor.xcodeproj/xcuserdata/andregrillo.xcuserdatad/xcschemes/xcschememanagement.plist b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.xcodeproj/xcuserdata/andregrillo.xcuserdatad/xcschemes/xcschememanagement.plist
new file mode 100644
index 0000000..689215c
--- /dev/null
+++ b/src/ios/libs/OSPhotoEditor/OSPhotoEditor.xcodeproj/xcuserdata/andregrillo.xcuserdatad/xcschemes/xcschememanagement.plist
@@ -0,0 +1,19 @@
+
+
+
+
+ SchemeUserState
+
+ OSPhotoEditor-Universal.xcscheme_^#shared#^_
+
+ orderHint
+ 1
+
+ OSPhotoEditor.xcscheme_^#shared#^_
+
+ orderHint
+ 0
+
+
+
+
diff --git a/node_modules/xcode/lib/pbxProject.js b/node_modules/xcode/lib/pbxProject.js
index 0e0f8f9..3097678 100644
--- a/node_modules/xcode/lib/pbxProject.js
+++ b/node_modules/xcode/lib/pbxProject.js
@@ -1476,14 +1476,42 @@ pbxProject.prototype.addTarget = function(name, type, subfolder) {
this.addToPbxCopyfilesBuildPhase(productFile)
// this.addBuildPhaseToTarget(newPhase.buildPhase, this.getFirstTarget().uuid)
-
- };
+ } else if (targetType === 'watch2_app') {
+ // Create CopyFiles phase in first target
+ this.addBuildPhase(
+ [targetName + '.app'],
+ 'PBXCopyFilesBuildPhase',
+ 'Embed Watch Content',
+ this.getFirstTarget().uuid,
+ targetType,
+ '"$(CONTENTS_FOLDER_PATH)/Watch"'
+ );
+ } else if (targetType === 'watch2_extension') {
+ // Create CopyFiles phase in watch target (if exists)
+ var watch2Target = this.getTarget(producttypeForTargettype('watch2_app'));
+ if (watch2Target) {
+ this.addBuildPhase(
+ [targetName + '.appex'],
+ 'PBXCopyFilesBuildPhase',
+ 'Embed App Extensions',
+ watch2Target.uuid,
+ targetType
+ );
+ }
+ }
// Target: Add uuid to root project
this.addToPbxProjectSection(target);
- // Target: Add dependency for this target to first (main) target
- this.addTargetDependency(this.getFirstTarget().uuid, [target.uuid]);
+ // Target: Add dependency for this target to other targets
+ if (targetType === 'watch2_extension') {
+ var watch2Target = this.getTarget(producttypeForTargettype('watch2_app'));
+ if (watch2Target) {
+ this.addTargetDependency(watch2Target.uuid, [target.uuid]);
+ }
+ } else {
+ this.addTargetDependency(this.getFirstTarget().uuid, [target.uuid]);
+ }
// Return target on success
@@ -1491,20 +1519,6 @@ pbxProject.prototype.addTarget = function(name, type, subfolder) {
};
-// helper recursive prop search+replace
-function propReplace(obj, prop, value) {
- var o = {};
- for (var p in obj) {
- if (o.hasOwnProperty.call(obj, p)) {
- if (typeof obj[p] == 'object' && !Array.isArray(obj[p])) {
- propReplace(obj[p], prop, value);
- } else if (p == prop) {
- obj[p] = value;
- }
- }
- }
-}
-
// helper object creation functions
function pbxBuildFileObj(file) {
var obj = Object.create(null);
@@ -1564,7 +1578,9 @@ function pbxCopyFilesBuildPhaseObj(obj, folderType, subfolderPath, phaseName) {
static_library: 'products_directory',
unit_test_bundle: 'wrapper',
watch_app: 'wrapper',
- watch_extension: 'plugins'
+ watch2_app: 'products_directory',
+ watch_extension: 'plugins',
+ watch2_extension: 'plugins'
}
var SUBFOLDERSPEC_BY_DESTINATION = {
absolute_path: 0,
@@ -1697,7 +1713,9 @@ function producttypeForTargettype (targetType) {
static_library: 'com.apple.product-type.library.static',
unit_test_bundle: 'com.apple.product-type.bundle.unit-test',
watch_app: 'com.apple.product-type.application.watchapp',
- watch_extension: 'com.apple.product-type.watchkit-extension'
+ watch2_app: 'com.apple.product-type.application.watchapp2',
+ watch_extension: 'com.apple.product-type.watchkit-extension',
+ watch2_extension: 'com.apple.product-type.watchkit2-extension'
};
return PRODUCTTYPE_BY_TARGETTYPE[targetType]
@@ -1715,7 +1733,9 @@ function filetypeForProducttype (productType) {
'com.apple.product-type.library.static': '"archive.ar"',
'com.apple.product-type.bundle.unit-test': '"wrapper.cfbundle"',
'com.apple.product-type.application.watchapp': '"wrapper.application"',
- 'com.apple.product-type.watchkit-extension': '"wrapper.app-extension"'
+ 'com.apple.product-type.application.watchapp2': '"wrapper.application"',
+ 'com.apple.product-type.watchkit-extension': '"wrapper.app-extension"',
+ 'com.apple.product-type.watchkit2-extension': '"wrapper.app-extension"'
};
return FILETYPE_BY_PRODUCTTYPE[productType]
@@ -1739,8 +1759,7 @@ pbxProject.prototype.getFirstProject = function() {
}
pbxProject.prototype.getFirstTarget = function() {
-
- // Get first targets UUID
+ // Get first target's UUID
var firstTargetUuid = this.getFirstProject()['firstProject']['targets'][0].value;
// Get first pbxNativeTarget
@@ -1752,6 +1771,26 @@ pbxProject.prototype.getFirstTarget = function() {
}
}
+pbxProject.prototype.getTarget = function(productType) {
+ // Find target by product type
+ var targets = this.getFirstProject()['firstProject']['targets'];
+ var nativeTargets = this.pbxNativeTargetSection();
+ for (var i = 0; i < targets.length; i++) {
+ var target = targets[i];
+ var targetUuid = target.value;
+ if (nativeTargets[targetUuid]['productType'] === '"' + productType + '"') {
+ // Get pbxNativeTarget
+ var nativeTarget = this.pbxNativeTargetSection()[targetUuid];
+ return {
+ uuid: targetUuid,
+ target: nativeTarget
+ };
+ }
+ }
+
+ return null;
+}
+
/*** NEW ***/
pbxProject.prototype.addToPbxGroupType = function (file, groupKey, groupType) {